get file = 'ch.sav'.

select if (UF9 = 1).
select if (cage >= 12).

weight by chweight.

compute notmeas = 0.
if (AN4 <> 1) notmeas = 100.
variable label notmeas "Children not measured".

compute missage = 0.
if (notmeas = 0 & (UF10M >= 96 or UF10Y >= 9996)) missage = 100.
variable label missage "Missing month or year of birth".

compute misshw = 0.
if (notmeas = 0 & (AN1 >= 99.0 or AN2 >= 999.0)) misshw = 100.
variable label misshw "Missing height or weight".

compute missflag = 0.
if (notmeas = 0 & missage = 0 & misshw = 0 & flag <> 0) missflag = 100.
variable label missflag "Other flagged cases".

compute totflag = 0.
if (notmeas = 100 or missage = 100 or misshw = 100 or flag <> 0) totflag = 100.
variable label totflag "Total cases excluded from analysis".

* For Tajikistan: Collapsing  education level "None" with "Non standard/missing/DK".
*recode melevel (1, 9 = 1).
*Value label melevel
*  1 "None/Non-standard/ Missing/DK"
*  2 "Primary"
*  3 "Incomplete Secondary"
*  4 "Complete Secondary"
*  5 "Secondary special"
*  6 "Higher education".

* For Tajikistan: Collapsing "Russian" and "Kyrgiz",  nationality to "Other".
recode HC1B (3,4 = 6).

tables
  /format = zero
  /observation = notmeas misshw missage missflag totflag
  /ftotal = tot1 "Total" tot2 "Number of children"
  /table = HL4 + HH7 + HH6 + cage_6 + melevel + wlthind5 + HC1B + tot1 
		by notmeas + misshw + missage + missflag + totflag + tot2
  /statistics
    mean(notmeas (f5.1) '')
    mean(misshw (f5.1) '')
    mean(missage (f5.1) '')
    mean(missflag (f5.1) '')
    mean(totflag (f5.1) '')
    count(tot2 (f5.0) '')
  /title
    "Table NU.1-Aw: Child malnourishment (Working table)"
		"Percentage of under-five children not measured, measured with missing height or weight, missing month or year of birth, "+
                        "or other flagged cases, and total cases excluded from analysis, Tajikistan, 2005".

select if (FLAG = 0).

do if (misshw = 0).
+ recode an2aa (LO thru 10.9 = 100) (else = 0) into muac1.
+ recode an2aa (11.0 thru 11.9 = 100) (else = 0) into muac2.
+ recode an2aa (12.0 thru 12.4 = 100) (else = 0) into muac3.
+ recode an2aa (12.5 thru 13.4 = 100) (else = 0) into muac4.
+ recode an2aa (13.5 thru HI = 100) (else = 0) into muac5.
+ recode WHZ (-2.00 thru hi = 0) (else = 100) into wh2.
+ recode WHZ (-3.00 thru hi = 0) (else = 100) into wh3.
+ recode WHZ (lo thru +2.00 = 0) (else = 100) into wh3a.
else.
+ compute muac1 = 9.
+ compute muac2 = 9.
+ compute muac3 = 9.
+ compute muac4 = 9.
+ compute muac5 = 9.
+ compute wh2 = 9.
+ compute wh3 = 9.
+ compute wh3a = 9.
end if.
variable label muac1 "MUAC <110 mm".
variable label muac2 "MUAC 110-119 mm".
variable label muac3 "MUAC 120-124 mm".
variable label muac4 "MUAC 125-134 mm".
variable label muac5 "MUAC >=135 mm".
variable label wh2 "Weight for height: % below -2SD".
variable label wh3 "Weight for height: % below -3SD".
variable label wh3a "Weight for height: % above +2SD".

missing values muac1 muac2 muac3 muac4 muac5 wh2 wh3 wh3a (9).

compute GAM2=0.
if (whz < -2 or an2aa < 12.5) GAM2 = 100.
variable label GAM2 "Global Acute Malnutrition: % (WHZ < -2SD or MUAC <125mm)".

compute GAM2e=0.
if (whz < -2 or an2aa < 12.5 or an2bb = 1) GAM2e = 100.
variable label GAM2e "Global Acute Malnutrition: % (WHZ < -2SD or MUAC <125mm or Edema)".

compute GAM3=0.
if (whz < -3 or an2aa < 11.0) GAM3 = 100.
variable label GAM3 "Severe Global Acute Malnutrition: % (WHZ < -3SD or MUAC <110mm)".

compute GAM3e=0.
if (whz < -3 or an2aa < 11.0 or an2bb = 1) GAM3e = 100.
variable label GAM3e "Severe Global Acute Malnutrition: % (WHZ < -3SD or MUAC <110mm or Edema)".

compute EDEMA=0.
if (an2bb = 1) EDEMA = 100.
variable label EDEMA " % Children with Edema".

compute hi75=0.
if (an2 >= 75) hi75 = 100.
variable label hi75 "Height".
value label hi75
0 " < 75 cm"
100 ">=75 cm".

* For Tajikistan: Collapsing  education level "None" with "Non standard/missing/DK".
*recode melevel (1, 9 = 1).
* Value label melevel
*  1 "None/Non-standard/ Missing/DK"
*  2 "Primary"
*  3 "Incomplete Secondary"
*  4 "Complete Secondary"
*  5 "Secondary special"
*  6 "Higher education".

* For Tajikistan: Collapsing "Russian" and "Kyrgiz",  nationality to "Other".
recode HC1B (3,4 = 6).


tables
  /format = zero
  /observation = muac1 muac2 muac3 muac4 muac5 edema wh2 wh3 wh3a gam2 gam2e gam3 gam3e
  /ftotal = tot1 "Total" tot2 "Number of children"
  /table = HL4 + HH7 + HH6 + cage_6 + hi75 + melevel + wlthind5 + HC1B + tot1 
		by muac1 + muac2 + muac3 + muac4 + muac5+ edema + wh2 + wh3 + wh3a + gam2 + gam2e + gam3 + gam3e + tot2
  /statistics
    mean(muac1 (f5.1) '')
    mean(muac2 (f5.1) '')
    mean(muac3 (f5.1) '')
    mean(muac4 (f5.1) '')
    mean(muac5 (f5.1) '')
    mean(edema (f5.1) '')
    mean(wh2 (f5.1) '')
    mean(wh3 (f5.1) '')
    mean(wh3a (f5.1) '')
    mean(gam2 (f5.1) '')
    mean(gam2e (f5.1) '')
    mean(gam3 (f5.1) '')
    mean(gam3e (f5.1) '')
    count(tot2 (f5.0) '')
  /title
    "Table NU.1A: Child acute malnutrition" 
		"Percentage of children 12 to 59 months of age exposed to "+
		"acute severe or moderate malnutrition, Tajikistan, 2005"
  /caption
    "* Country specific indicator".

new file.
