*** This program ASSUMES that your questionnaire contains questions about the 
*** HIB vaccination. If you don't have questions about the HIB vaccination,
*** remove the variables HIB1, HIB2 and HIB3 from this program.
*** For countries that do have questions about HIB, this program assumes that
*** they are named as follows:
***   IM7AD, IM7AM, IM7AY --- HIB1 in vaccination table
***   IM7BD, IM7BM, IM7BY --- HIB2 in vaccination table
***   IM7CD, IM7CM, IM7CY --- HIB3 in vaccination table
***   IM17A               --- Ever been given HIB vaccination
***   IM17B               --- Number of HIB vaccinations received
*** If your variable names are different, change the program accordingly
*** Tajikistan has 3 Hepatitis B doses in the immunization schedule
*** Coverage was assessed in the cohort 15-26 months of age 
*** in order to accomodate Measles vaccine, which is given at 12 months of age
*** Three sources of data was used - medical facility based immunization records,
*** HH based immunization card and mother's recall.

get file = 'ch.sav'.

include file = "04 - chrecvac.sps".

select if (UF9 = 1).

weight by chweight.

select if (cage >= 15 and cage <= 26).


compute total = 1.
variable label total "Number of children".
value label total 1 "".

recode hepb1 (1,2 = 100) (3 = 0) into hepb1_r.
variable label hepb1_r "".

recode hepb2 (1,2 = 100) (3 = 0) into hepb2_r.
variable label hepb2_r "".

recode hepb3 (1,2 = 100) (3 = 0) into hepb3_r.
variable label hepb3_r "".

recode hasvcard (1 = 100) (2 = 0) into card_r.
variable label card_r "".

* For Tajikistan: Collapsing "Russian" and "Kyrgiz",  nationality to "Other".
recode HC1B (3,4 = 6).

tables
  /format = zero
  /observation = hepb1_r hepb2_r hepb3_r card_r
  /ftotal = tot1 "Total"
  /table = HL4 + HH7 + HH6 + melevel + wlthind5 + HC1B + hasvcard + tot1 by 
		hepb1_r + hepb2_r + hepb3_r + card_r
  /statistics
    mean(hepb1_r (f5.1) 'HepB1')
    mean(hepb2_r (f5.1) 'HepB2')
    mean(hepb3_r (f5.1) 'HepB3')
    mean(card_r (f5.1) 'Percent with health card')
    validn(card_r (f5.0) 'Number of children aged 15-26 months')
  /title
    "Table CH.2c: Vaccinations by background characteristics (continued)"
		"Percentage of children aged 15-26 months currently vaccinated against "+
		"childhood diseases, Tajikistan, 2005".

new file.
